@@ -26,6 +26,9 @@ crew_controller_lsf <- function(
   workers = 1L,
   host = NULL,
   port = NULL,
+  tls = crew::crew_tls(),
+  tls_enable = NULL,
+  tls_config = NULL,
   seconds_interval = 0.25,
   seconds_timeout = 10,
   seconds_launch = 86400,
@@ -38,6 +41,7 @@ crew_controller_lsf <- function(
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
+  launch_max = 5L,
   verbose = FALSE,
   command_submit = as.character(Sys.which("bsub")),
   command_delete = as.character(Sys.which("bkill")),
@@ -50,12 +54,14 @@ crew_controller_lsf <- function(
   lsf_memory_gigabytes_required = NULL,
   lsf_cores = NULL
 ) {
-  # TODO: remove eval parse after next crew release.
-  client <- eval(parse(text = "crew::crew_client"))(
+  client <- crew::crew_client(
     name = name,
     workers = workers,
     host = host,
     port = port,
+    tls = tls,
+    tls_enable = tls_enable,
+    tls_config = tls_config,
     seconds_interval = seconds_interval,
     seconds_timeout = seconds_timeout
   )
@@ -72,6 +78,8 @@ crew_controller_lsf <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
+    launch_max = launch_max,
+    tls = tls,
     verbose = verbose,
     command_submit = command_submit,
     command_delete = command_delete,
