@@ -44,6 +44,8 @@ crew_launcher_cluster <- function(
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
+  launch_max = 5L,
+  tls = crew::crew_tls(),
   verbose = FALSE,
   command_submit = "",
   command_delete = "",
@@ -64,6 +66,8 @@ crew_launcher_cluster <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
+    launch_max = launch_max,
+    tls = tls,
     verbose = verbose,
     command_submit = command_submit,
     command_delete = command_delete,
@@ -111,6 +115,8 @@ crew_class_launcher_cluster <- R6::R6Class(
     #' @param reset_packages See [crew_launcher_cluster()].
     #' @param reset_options See [crew_launcher_cluster()].
     #' @param garbage_collection See [crew_launcher_cluster()].
+    #' @param launch_max See [crew_launcher_cluster()].
+    #' @param tls See [crew_launcher_cluster()].
     #' @param verbose See [crew_launcher_cluster()].
     #' @param command_submit See [crew_launcher_cluster()].
     #' @param command_delete See [crew_launcher_cluster()].
@@ -129,6 +135,8 @@ crew_class_launcher_cluster <- R6::R6Class(
       reset_packages = NULL,
       reset_options = NULL,
       garbage_collection = NULL,
+      launch_max = NULL,
+      tls = NULL,
       verbose = NULL,
       command_submit = NULL,
       command_delete = NULL,
@@ -147,7 +155,9 @@ crew_class_launcher_cluster <- R6::R6Class(
         reset_globals = reset_globals,
         reset_packages = reset_packages,
         reset_options = reset_options,
-        garbage_collection = garbage_collection
+        garbage_collection = garbage_collection,
+        launch_max = launch_max,
+        tls = tls
       )
       self$verbose <- verbose
       self$command_submit <- command_submit
