@@ -68,6 +68,8 @@ crew_launcher_lsf <- function(
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
+  launch_max = 5L,
+  tls = crew::crew_tls(),
   verbose = FALSE,
   command_submit = as.character(Sys.which("bsub")),
   command_delete = as.character(Sys.which("bkill")),
@@ -94,6 +96,8 @@ crew_launcher_lsf <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
+    launch_max = launch_max,
+    tls = tls,
     verbose = verbose,
     command_submit = command_submit,
     command_delete = command_delete,
@@ -147,6 +151,8 @@ crew_class_launcher_lsf <- R6::R6Class(
     #' @param reset_packages See [crew_launcher_lsf()].
     #' @param reset_options See [crew_launcher_lsf()].
     #' @param garbage_collection See [crew_launcher_lsf()].
+    #' @param launch_max See [crew_launcher_lsf()].
+    #' @param tls See [crew_launcher_lsf()].
     #' @param verbose See [crew_launcher_lsf()].
     #' @param command_submit See [crew_launcher_lsf()].
     #' @param command_delete See [crew_launcher_lsf()].
@@ -171,6 +177,8 @@ crew_class_launcher_lsf <- R6::R6Class(
       reset_packages = NULL,
       reset_options = NULL,
       garbage_collection = NULL,
+      launch_max = NULL,
+      tls = NULL,
       verbose = NULL,
       command_submit = NULL,
       command_delete = NULL,
@@ -196,6 +204,8 @@ crew_class_launcher_lsf <- R6::R6Class(
         reset_packages = reset_packages,
         reset_options = reset_options,
         garbage_collection = garbage_collection,
+        launch_max = launch_max,
+        tls = tls,
         verbose = verbose,
         command_submit = command_submit,
         command_delete = command_delete,
