@@ -1,10 +1,8 @@
 test_that("valid simple crew_launcher_slurm()", {
-  skip_if_low_dep_versions()
   expect_silent(crew_launcher_slurm())
 })
 
 test_that("valid populated crew_launcher_slurm()", {
-  skip_if_low_dep_versions()
   expect_silent(
     crew_launcher_slurm(
       script_lines = c("module load R", "echo 'start'"),
@@ -17,22 +15,19 @@ test_that("valid populated crew_launcher_slurm()", {
 })
 
 test_that("invalid crew_launcher_slurm(): SLURM field", {
-  skip_if_low_dep_versions()
   x <- crew_launcher_slurm()
   x$slurm_cpus_per_task <- - 1L
   expect_error(x$validate(), class = "crew_error")
 })
 
 test_that("invalid crew_launcher_slurm(): non-SLURM field", {
-  skip_if_low_dep_versions()
   x <- crew_launcher_slurm()
   x$name <- - 1L
   expect_error(x$validate(), class = "crew_error")
 })
 
 test_that("crew_launcher_slurm() script() nearly empty", {
-  skip_if_low_dep_versions()
-  x <- crew_launcher_slurm()
+  x <- crew_launcher_slurm(slurm_time_minutes = NULL)
   lines <- c(
     "#!/bin/sh",
     "#SBATCH --job-name=a_job",
@@ -43,13 +38,13 @@ test_that("crew_launcher_slurm() script() nearly empty", {
 })
 
 test_that("crew_launcher_slurm() script() all lines", {
-  skip_if_low_dep_versions()
   x <- crew_launcher_slurm(
     script_lines = c("module load R", "echo 'start'"),
     slurm_log_output = "log1",
     slurm_log_error = "log2",
     slurm_memory_gigabytes_per_cpu = 2.096,
-    slurm_cpus_per_task = 2
+    slurm_cpus_per_task = 2,
+    slurm_time_minutes = 57
   )
   out <- x$script(name = "this_job")
   exp <- c(
@@ -57,8 +52,9 @@ test_that("crew_launcher_slurm() script() all lines", {
     "#SBATCH --job-name=this_job",
     "#SBATCH --output=log1",
     "#SBATCH --error=log2",
-    "#SBATCH --mem-per-cpu=2.096G",
+    "#SBATCH --mem-per-cpu=2146M",
     "#SBATCH --cpus-per-task=2",
+    "#SBATCH --time=57",
     "module load R",
     "echo 'start'"
   )
@@ -66,7 +62,6 @@ test_that("crew_launcher_slurm() script() all lines", {
 })
 
 test_that("args_terminate()", {
-  skip_if_low_dep_versions()
   x <- crew_launcher_slurm()
   expect_equal(
     x$args_terminate(name = "my_job"),
